==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_functions/mp3291_001/ChangeEquipmentNumber.java <==

package net.datastream.schemas.mp_functions.mp3291_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENTEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEWEQUIPMENTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "currentequipmentid",
    "newequipmentid"
})
@XmlRootElement(name = "ChangeEquipmentNumber")
public class ChangeEquipmentNumber {

    @XmlElement(name = "CURRENTEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type currentequipmentid;
    @XmlElement(name = "NEWEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type newequipmentid;

    /**
     * Obtient la valeur de la propriété currentequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getCURRENTEQUIPMENTID() {
        return currentequipmentid;
    }

    /**
     * Définit la valeur de la propriété currentequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setCURRENTEQUIPMENTID(EQUIPMENTID_Type value) {
        this.currentequipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété newequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getNEWEQUIPMENTID() {
        return newequipmentid;
    }

    /**
     * Définit la valeur de la propriété newequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setNEWEQUIPMENTID(EQUIPMENTID_Type value) {
        this.newequipmentid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_functions/mp3291_001/ChangeEquipmentNumber.java <==

package net.datastream.schemas.mp_functions.mp3291_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENTEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEWEQUIPMENTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "currentequipmentid",
    "newequipmentid"
})
@XmlRootElement(name = "ChangeEquipmentNumber")
public class ChangeEquipmentNumber {

    @XmlElement(name = "CURRENTEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type currentequipmentid;
    @XmlElement(name = "NEWEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type newequipmentid;

    /**
     * Gets the value of the currentequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getCURRENTEQUIPMENTID() {
        return currentequipmentid;
    }

    /**
     * Sets the value of the currentequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setCURRENTEQUIPMENTID(EQUIPMENTID_Type value) {
        this.currentequipmentid = value;
    }

    /**
     * Gets the value of the newequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getNEWEQUIPMENTID() {
        return newequipmentid;
    }

    /**
     * Sets the value of the newequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setNEWEQUIPMENTID(EQUIPMENTID_Type value) {
        this.newequipmentid = value;
    }

}
